@@ -36,6 +36,7 @@ EXECUTE 'ALTER FUNCTION  ST_force_3d(geometry ) SET search_path=' || quote_ident
 EXECUTE 'ALTER FUNCTION  ST_force_3dm(geometry ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
 EXECUTE 'ALTER FUNCTION  ST_force_4d(geometry ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
 EXECUTE 'ALTER FUNCTION  ST_force_collection(geometry ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
+EXECUTE 'ALTER FUNCTION  ST_ForcePolygonCCW(geometry ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
 EXECUTE 'ALTER FUNCTION  ST_Affine(geometry,float8,float8,float8,float8,float8,float8 ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
 EXECUTE 'ALTER FUNCTION  ST_Rotate(geometry,float8 ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
 EXECUTE 'ALTER FUNCTION  ST_Rotate(geometry,float8,float8,float8 ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
@@ -48,7 +49,6 @@ EXECUTE 'ALTER FUNCTION  ST_Translate(geometry,float8,float8 ) SET search_path='
 EXECUTE 'ALTER FUNCTION  ST_Scale(geometry,float8,float8,float8 ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
 EXECUTE 'ALTER FUNCTION  ST_Scale(geometry,float8,float8 ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
 EXECUTE 'ALTER FUNCTION  ST_Transscale(geometry,float8,float8,float8,float8 ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
-EXECUTE 'ALTER FUNCTION  _ST_DumpPoints(the_geom geometry, cur_path integer[] ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
 EXECUTE 'ALTER FUNCTION  populate_geometry_columns(use_typmod boolean  ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
 EXECUTE 'ALTER FUNCTION  populate_geometry_columns(tbl_oid oid, use_typmod boolean  ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
 EXECUTE 'ALTER FUNCTION  UpdateGeometrySRID(catalogn_name varchar,schema_name varchar,table_name varchar,column_name varchar,new_srid_in integer ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
@@ -57,6 +57,9 @@ EXECUTE 'ALTER FUNCTION  UpdateGeometrySRID(varchar,varchar,integer ) SET search
 EXECUTE 'ALTER FUNCTION  find_srid(varchar,varchar,varchar ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
 EXECUTE 'ALTER FUNCTION  get_proj4_from_srid(integer ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
 EXECUTE 'ALTER FUNCTION  ST_Transform(geometry,integer ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
+EXECUTE 'ALTER FUNCTION  ST_Transform(geom geometry, to_proj text ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
+EXECUTE 'ALTER FUNCTION  ST_Transform(geom geometry, from_proj text, to_proj text ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
+EXECUTE 'ALTER FUNCTION  ST_Transform(geom geometry, from_proj text, to_srid integer ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
 EXECUTE 'ALTER FUNCTION  postgis_full_version( ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
 EXECUTE 'ALTER FUNCTION  ST_SnapToGrid(geometry, float8, float8 ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
 EXECUTE 'ALTER FUNCTION  ST_SnapToGrid(geometry, float8 ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
@@ -136,6 +139,7 @@ EXECUTE 'ALTER FUNCTION  EnableLongTransactions( ) SET search_path=' || quote_id
 EXECUTE 'ALTER FUNCTION  LongTransactionsEnabled( ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
 EXECUTE 'ALTER FUNCTION  DisableLongTransactions( ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
 EXECUTE 'ALTER FUNCTION  ST_AsText(text ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
+EXECUTE 'ALTER FUNCTION  overlaps_geog(geography, gidx ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
 EXECUTE 'ALTER FUNCTION  ST_AsSVG(text ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
 EXECUTE 'ALTER FUNCTION  ST_AsGML(text ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
 EXECUTE 'ALTER FUNCTION  ST_AsGML(geog geography, maxdecimaldigits int4 , options int4  ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
@@ -154,20 +158,29 @@ EXECUTE 'ALTER FUNCTION  ST_Area(text ) SET search_path=' || quote_ident(param_p
 EXECUTE 'ALTER FUNCTION  ST_Length(text ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
 EXECUTE 'ALTER FUNCTION  _ST_BestSRID(geography ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
 EXECUTE 'ALTER FUNCTION  ST_Buffer(geography, float8 ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
+EXECUTE 'ALTER FUNCTION  ST_Buffer(geography, float8, integer ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
+EXECUTE 'ALTER FUNCTION  ST_Buffer(geography, float8, text ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
 EXECUTE 'ALTER FUNCTION  ST_Buffer(text, float8 ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
+EXECUTE 'ALTER FUNCTION  ST_Buffer(text, float8, integer ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
+EXECUTE 'ALTER FUNCTION  ST_Buffer(text, float8, text ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
 EXECUTE 'ALTER FUNCTION  ST_Intersection(geography, geography ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
 EXECUTE 'ALTER FUNCTION  ST_Intersection(text, text ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
 EXECUTE 'ALTER FUNCTION  ST_AsBinary(geography,text ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
 EXECUTE 'ALTER FUNCTION  ST_AsEWKT(text ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
+EXECUTE 'ALTER FUNCTION  ST_Centroid(text ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
 EXECUTE 'ALTER FUNCTION  ST_DistanceSphere(geom1 geometry, geom2 geometry ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
 EXECUTE 'ALTER FUNCTION  ST_distance_sphere(geom1 geometry, geom2 geometry ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
 EXECUTE 'ALTER FUNCTION  postgis_type_name(geomname varchar, coord_dimension integer, use_new_name boolean  ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
 EXECUTE 'ALTER FUNCTION  postgis_constraint_srid(geomschema text, geomtable text, geomcolumn text ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
 EXECUTE 'ALTER FUNCTION  postgis_constraint_dims(geomschema text, geomtable text, geomcolumn text ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
 EXECUTE 'ALTER FUNCTION  postgis_constraint_type(geomschema text, geomtable text, geomcolumn text ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
+EXECUTE 'ALTER FUNCTION  ST_CurveToLine(geometry, integer ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
 EXECUTE 'ALTER FUNCTION  ST_CurveToLine(geometry ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
 EXECUTE 'ALTER FUNCTION  ST_Polygon(geometry, int ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
-EXECUTE 'ALTER FUNCTION  ST_MinimumBoundingCircle(inputgeom geometry, segs_per_quarter integer  ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
+EXECUTE 'ALTER FUNCTION  contains_2d(geometry, box2df ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
+EXECUTE 'ALTER FUNCTION  is_contained_2d(geometry, box2df ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
+EXECUTE 'ALTER FUNCTION  overlaps_2d(geometry, box2df ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
+EXECUTE 'ALTER FUNCTION  overlaps_nd(geometry, gidx ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
 EXECUTE 'ALTER FUNCTION  _st_concavehull(param_inputgeom geometry ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
 EXECUTE 'ALTER FUNCTION  ST_ConcaveHull(param_geom geometry, param_pctconvex float, param_allow_holes boolean  ) SET search_path=' || quote_ident(param_postgis_schema) || ',pg_catalog;';
 END;$$;
\ No newline at end of file
